@@ -1,19 +1,22 @@
 package WebService::ThrowAwayMail;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Moo;
-use MooX::LazierAttributes;
+use MooX::LazierAttributes qw/rw lzy/;
+use MooX::ValidateSubs;
 use Types::Standard qw/Object Str/;
  
 use HTTP::Tiny;
 use Carp qw/croak/;
 
 attributes (
-    tiny => [rw, Object, {lzy, default => sub {HTTP::Tiny->new}}],
-    base_url => [Str, {lzy, default => 'https://throwawaymail.org/getalias/text'}],
+    tiny => [rw, Object,{lzy, default => sub {HTTP::Tiny->new}}],
+    base_url => [Str, { lzy, default => 'https://throwawaymail.org/getalias/text'}],
 );
 
+validate_subs [qw/get get_alias/] => [];
+
 sub get {
     my $response = $_[0]->tiny->get($_[0]->base_url);
     $response->{success} and return $response;
@@ -35,7 +38,7 @@ WebService::ThrowAwayMail - Perl client for throwawaymail.org API
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
